@@ -289,7 +289,7 @@ class Recipe(zc.recipe.egg.Eggs):
         if patch_options:
             patch_options = patch_options.split(' ')
         else:
-            patch_options = '-p1'
+            patch_options = ['-p1']
         gae = os.path.join(self.buildout['buildout']['parts-directory'],
                            'google_appengine')
         os.chdir(gae)
